==> telegraph-0.1.7-x86_64-1_gfs.txz: usr/doc/telegraph-0.1.7/README.md <==
<h1 align="center">
  <img src="data/icons/hicolor/scalable/apps/io.github.fkinoshita.Telegraph.svg" alt="Telegraph Icon" width="192" height="192"/>
  <br>
  Telegraph
</h1>

<p align="center"><strong>Write and decode morse</strong></p>

<p align="center">
  <a href="https://flathub.org/apps/details/io.github.fkinoshita.Telegraph">
    <img width="200" alt="Download on Flathub" src="https://flathub.org/assets/badges/flathub-badge-en.svg"/>
  </a>
  <br>
</p>

<p align="center">
  <a href="https://apps.gnome.org/app/io.github.fkinoshita.Telegraph">
    <img src="https://circle.gnome.org/assets/button/badge.svg" alt="GNOME Circle"/>
  </a>
  <a href="https://flathub.org/apps/details/io.github.fkinoshita.Telegraph">
    <img alt="Flathub downloads" src="https://img.shields.io/badge/dynamic/json?color=informational&label=downloads&logo=flathub&logoColor=white&query=%24.installs_total&url=https%3A%2F%2Fflathub.org%2Fapi%2Fv2%2Fstats%2Fio.github.fkinoshita.Telegraph"/>
  </a>
</p>


<p align="center">
  <img src="/data/screenshots/telegraph.png" alt="Preview"/>
</p>

Telegraph is a simple Morse translator, start typing your message to see
the resulting Morse code and vice versa.



## Installation

Install Telegraph from Flathub by issuing
```shell
$ flatpak install io.github.fkinoshita.Telegraph
```
Telegraph can be kept up to date by issuing flatpak's update command like
```shell
$ flatpak update
```

## Code of conduct

Telegraph follows the GNOME project [Code of Conduct](./code-of-conduct.md). All
communications in project spaces, such as the issue tracker are expected to follow it.

==> telegraph-0.1.8-x86_64-1_gfs.txz: usr/doc/telegraph-0.1.8/README.md <==
<h1 align="center">
  <img src="data/icons/hicolor/scalable/apps/io.github.fkinoshita.Telegraph.svg" alt="Telegraph Icon" width="192" height="192"/>
  <br>
  Telegraph
</h1>

<p align="center"><strong>Write and decode morse</strong></p>

<p align="center">
  <a href="https://flathub.org/apps/details/io.github.fkinoshita.Telegraph">
    <img width="200" alt="Download on Flathub" src="https://flathub.org/assets/badges/flathub-badge-en.svg"/>
  </a>
  <br>
</p>

<p align="center">
  <a href="https://apps.gnome.org/Telegraph/">
    <img src="https://circle.gnome.org/assets/button/badge.svg" alt="GNOME Circle"/>
  </a>
  <a href="https://flathub.org/apps/details/io.github.fkinoshita.Telegraph">
    <img alt="Flathub downloads" src="https://img.shields.io/badge/dynamic/json?color=informational&label=downloads&logo=flathub&logoColor=white&query=%24.installs_total&url=https%3A%2F%2Fflathub.org%2Fapi%2Fv2%2Fstats%2Fio.github.fkinoshita.Telegraph"/>
  </a>
</p>


<p align="center">
  <img src="/data/screenshots/telegraph.png" alt="Preview"/>
</p>

Telegraph is a simple Morse translator, start typing your message to see
the resulting Morse code and vice versa.



## Installation

Install Telegraph from Flathub by issuing
```shell
$ flatpak install io.github.fkinoshita.Telegraph
```
Telegraph can be kept up to date by issuing flatpak's update command like
```shell
$ flatpak update
```

## Code of conduct

Telegraph follows the GNOME project [Code of Conduct](./code-of-conduct.md). All
communications in project spaces, such as the issue tracker are expected to follow it.
